@@ -9,7 +9,7 @@ has 'attachment_dir' => ( is => 'rw', isa => 'Str' );
 
 use base 'DBIx::Class::Schema';
 
-__PACKAGE__->load_classes;
+__PACKAGE__->load_namespaces( default_resultset_class => '+MojoMojo::Schema::Base::ResultSet' );
 
 sub create_initial_data {
     my $schema = shift;
